/*!
@ng-dynamic-forms/ui-bootstrap 5.4.7 2018-03-16 23:20 UTC
Copyright (c) 2016-2017, Udo Schöfer http://www.udos86.de

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted, provided that the above
copyright notice and this permission notice appear in all copies.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/
import { ChangeDetectorRef, Component, ContentChildren, EventEmitter, Input, Output, ViewChildren, NgModule } from '@angular/core';
import { ReactiveFormsModule } from '@angular/forms';
import { DynamicFormControlComponent, DynamicFormLayoutService, DynamicFormValidationService, DynamicTemplateDirective, DYNAMIC_FORM_CONTROL_TYPE_ARRAY, DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX, DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX_GROUP, DYNAMIC_FORM_CONTROL_TYPE_DATEPICKER, DYNAMIC_FORM_CONTROL_TYPE_GROUP, DYNAMIC_FORM_CONTROL_TYPE_INPUT, DYNAMIC_FORM_CONTROL_TYPE_RADIO_GROUP, DYNAMIC_FORM_CONTROL_TYPE_SELECT, DYNAMIC_FORM_CONTROL_TYPE_TEXTAREA, DYNAMIC_FORM_CONTROL_TYPE_TIMEPICKER, DynamicFormComponent, DynamicFormService, DynamicFormsCoreModule } from '@ng-dynamic-forms/core';
import { CommonModule } from '@angular/common';
import { BsDatepickerModule } from 'ngx-bootstrap/datepicker';
import { TimepickerModule } from 'ngx-bootstrap/timepicker';
import { TextMaskModule } from 'angular2-text-mask';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class DynamicBootstrapFormControlComponent extends DynamicFormControlComponent {
    /**
     * @param {?} changeDetectorRef
     * @param {?} layoutService
     * @param {?} validationService
     */
    constructor(changeDetectorRef, layoutService, validationService) {
        super(changeDetectorRef, layoutService, validationService);
        this.changeDetectorRef = changeDetectorRef;
        this.layoutService = layoutService;
        this.validationService = validationService;
        this.asBootstrapFormGroup = true;
        this.bindId = true;
        this.context = null;
        this.hasErrorMessaging = false;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
        this.customEvent = new EventEmitter();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        super.ngOnChanges(changes);
        if (changes["model"]) {
            this.type = DynamicBootstrapFormControlComponent.getFormControlType(this.model);
        }
    }
    /**
     * @param {?} model
     * @return {?}
     */
    static getFormControlType(model) {
        switch (model.type) {
            case DYNAMIC_FORM_CONTROL_TYPE_ARRAY:
                return 1 /* Array */;
            case DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX:
                return 2 /* Checkbox */;
            case DYNAMIC_FORM_CONTROL_TYPE_CHECKBOX_GROUP:
            case DYNAMIC_FORM_CONTROL_TYPE_GROUP:
                return 4 /* Group */;
            case DYNAMIC_FORM_CONTROL_TYPE_DATEPICKER:
                return 3 /* DatePicker */;
            case DYNAMIC_FORM_CONTROL_TYPE_INPUT:
                return 5 /* Input */;
            case DYNAMIC_FORM_CONTROL_TYPE_RADIO_GROUP:
                return 6 /* RadioGroup */;
            case DYNAMIC_FORM_CONTROL_TYPE_SELECT:
                return 7 /* Select */;
            case DYNAMIC_FORM_CONTROL_TYPE_TEXTAREA:
                return 8 /* TextArea */;
            case DYNAMIC_FORM_CONTROL_TYPE_TIMEPICKER:
                return 9 /* TimePicker */;
            default:
                return null;
        }
    }
}
DynamicBootstrapFormControlComponent.decorators = [
    { type: Component, args: [{
                selector: "dynamic-bootstrap-form-control,dynamic-form-bootstrap-control",
                template: "<div [class.form-group]=\"asBootstrapFormGroup || getClass('element', 'container').includes('form-group')\" [class.has-error]=\"showErrorMessages\" [formGroup]=\"group\" [ngClass]=\"[getClass('element', 'container'), getClass('grid', 'container')]\"><label *ngIf=\"type !== 2 && model.label\" [for]=\"model.id\" [innerHTML]=\"model.label\" [ngClass]=\"[getClass('element', 'label'), getClass('grid', 'label')]\"></label><ng-container *ngTemplateOutlet=\"templates[0]?.templateRef; context: model\"></ng-container><div *ngIf=\"type === 2\" [ngClass]=\"getClass('grid', 'control')\"><div [class.disabled]=\"model.disabled\" [ngClass]=\"getClass('element', 'control') || 'checkbox'\"><label><input type=\"checkbox\" [checked]=\"model.checked\" [dynamicId]=\"bindId && model.id\" [formControlName]=\"model.id\" [indeterminate]=\"model.indeterminate\" [name]=\"model.name\" [ngClass]=\"getClass('element', 'control')\" [required]=\"model.required\" [tabindex]=\"model.tabIndex\" [value]=\"model.value\" (blur)=\"onBlur($event)\" (change)=\"onValueChange($event)\" (focus)=\"onFocus($event)\"><span [innerHTML]=\"model.label\" [ngClass]=\"[getClass('element', 'label'), getClass('grid', 'label')]\"></span></label></div></div><div *ngIf=\"type !== 2\" [ngClass]=\"getClass('grid', 'control')\"><ng-container [ngSwitch]=\"type\"><div *ngSwitchCase=\"1\" [dynamicId]=\"bindId && model.id\" [formArrayName]=\"model.id\" [ngClass]=\"getClass('element', 'control')\"><div *ngFor=\"let groupModel of model.groups; let idx = index\" role=\"group\" [formGroupName]=\"idx\" [ngClass]=\"[getClass('element', 'group'), getClass('grid', 'group')]\"><dynamic-bootstrap-form-control *ngFor=\"let _model of groupModel.group\" [bindId]=\"false\" [context]=\"groupModel\" [group]=\"control.at(idx)\" [hasErrorMessaging]=\"_model.hasErrorMessages\" [hidden]=\"_model.hidden\" [layout]=\"layout\" [model]=\"_model\" [templates]=\"templateList\" [ngClass]=\"[getClass('element', 'host', _model), getClass('grid', 'host', _model)]\" (dfBlur)=\"onBlur($event)\" (dfChange)=\"onValueChange($event)\" (dfFocus)=\"onFocus($event)\"></dynamic-bootstrap-form-control><ng-container *ngTemplateOutlet=\"templates[2]?.templateRef; context: groupModel\"></ng-container></div></div><div *ngSwitchCase=\"3\" class=\"input-group\"><input bsDatepicker class=\"form-control\" #bsDatepicker=\"bsDatepicker\" [autofocus]=\"model.autoFocus\" [bsConfig]=\"getAdditional('bsConfig', {containerClass: getAdditional('containerClass', 'theme-green'), showWeekNumbers: getAdditional('showWeekNumbers', true)})\" [dynamicId]=\"bindId && model.id\" [formControlName]=\"model.id\" [maxDate]=\"model.max\" [minDate]=\"model.min\" [name]=\"model.name\" [ngClass]=\"getClass('element', 'control')\" [outsideClick]=\"getAdditional('outsideClick', true)\" [placeholder]=\"model.placeholder\" [placement]=\"getAdditional('placement', 'bottom')\" [readonly]=\"model.readOnly\" [required]=\"model.required\" (bsValueChange)=\"onValueChange($event)\" (onHidden)=\"onCustomEvent($event, 'onHidden')\" (onShown)=\"onCustomEvent($event, 'onShown')\"><div *ngIf=\"model.toggleLabel\" class=\"input-group-btn\"><button *ngIf=\"model.toggleIcon\" class=\"btn\" (click)=\"bsDatepicker.toggle()\"><img [src]=\"model.toggleIcon\"></button> <button *ngIf=\"model.toggleLabel\" class=\"btn\" (click)=\"bsDatepicker.toggle()\">{{ model.toggleLabel }}</button></div></div><fieldset *ngSwitchCase=\"4\" [dynamicId]=\"bindId && model.id\" [formGroupName]=\"model.id\" [name]=\"model.name\" [ngClass]=\"getClass('element', 'control')\"><legend *ngIf=\"model.legend\" [innerHTML]=\"model.legend\"></legend><dynamic-bootstrap-form-control *ngFor=\"let _model of model.group\" [asBootstrapFormGroup]=\"false\" [group]=\"control\" [hasErrorMessaging]=\"_model.hasErrorMessages\" [hidden]=\"_model.hidden\" [layout]=\"layout\" [model]=\"_model\" [templates]=\"templateList\" [ngClass]=\"[getClass('element', 'host', _model), getClass('grid', 'host', _model)]\" (dfBlur)=\"onBlur($event)\" (dfChange)=\"onValueChange($event)\" (dfFocus)=\"onFocus($event)\"></dynamic-bootstrap-form-control></fieldset><div *ngSwitchCase=\"5\" [class.input-group]=\"model.prefix || model.suffix\"><div *ngIf=\"model.prefix\" class=\"input-group-addon\" [innerHTML]=\"model.prefix\"></div><input class=\"form-control\" [attr.accept]=\"model.accept\" [attr.list]=\"model.listId\" [attr.max]=\"model.max\" [attr.min]=\"model.min\" [attr.multiple]=\"model.multiple\" [attr.step]=\"model.step\" [autocomplete]=\"model.autoComplete\" [autofocus]=\"model.autoFocus\" [dynamicId]=\"bindId && model.id\" [formControlName]=\"model.id\" [maxlength]=\"model.maxLength\" [minlength]=\"model.minLength\" [name]=\"model.name\" [ngClass]=\"getClass('element', 'control')\" [pattern]=\"model.pattern\" [placeholder]=\"model.placeholder\" [readonly]=\"model.readOnly\" [required]=\"model.required\" [spellcheck]=\"model.spellCheck\" [tabindex]=\"model.tabIndex\" [textMask]=\"{mask: (model.mask || false), showMask: model.mask && !(model.placeholder)}\" [type]=\"model.inputType\" (blur)=\"onBlur($event)\" (change)=\"onValueChange($event)\" (focus)=\"onFocus($event)\"><div *ngIf=\"model.suffix\" class=\"input-group-addon\" [innerHTML]=\"model.suffix\"></div><datalist *ngIf=\"hasList\" [id]=\"model.listId\"><option *ngFor=\"let option of model.list\" [value]=\"option\"></option></datalist></div><fieldset *ngSwitchCase=\"6\" role=\"radiogroup\" [dynamicId]=\"bindId && model.id\" [name]=\"model.name\" [ngClass]=\"getClass('element', 'control')\" [tabindex]=\"model.tabIndex\" (change)=\"onValueChange($event)\"><legend *ngIf=\"model.legend\" [innerHTML]=\"model.legend\"></legend><div *ngFor=\"let option of model.options$ | async\" [ngClass]=\"getClass('element', 'option') || 'radio'\"><label><input type=\"radio\" [formControlName]=\"model.id\" [name]=\"model.name\" [value]=\"option.value\" (blur)=\"onBlur($event)\" (focus)=\"onFocus($event)\"><span [innerHTML]=\"option.label\"></span></label></div></fieldset><select *ngSwitchCase=\"7\" class=\"form-control\" [dynamicId]=\"bindId && model.id\" [formControlName]=\"model.id\" [name]=\"model.name\" [ngClass]=\"getClass('element', 'control')\" [required]=\"model.required\" [tabindex]=\"model.tabIndex\" (blur)=\"onBlur($event)\" (change)=\"onValueChange($event)\" (focus)=\"onFocus($event)\"><option *ngFor=\"let option of model.options$ | async\" [disabled]=\"option.disabled\" [ngValue]=\"option.value\">{{ option.label }}</option></select> <textarea *ngSwitchCase=\"8\" class=\"form-control\" [dynamicId]=\"bindId && model.id\" [cols]=\"model.cols\" [formControlName]=\"model.id\" [maxlength]=\"model.maxLength\" [minlength]=\"model.minLength\" [name]=\"model.name\" [ngClass]=\"getClass('element', 'control')\" [placeholder]=\"model.placeholder\" [readonly]=\"model.readOnly\" [required]=\"model.required\" [rows]=\"model.rows\" [spellcheck]=\"model.spellCheck\" [tabindex]=\"model.tabIndex\" [wrap]=\"model.wrap\" (blur)=\"onBlur($event)\" (change)=\"onValueChange($event)\" (focus)=\"onFocus($event)\"></textarea> <span *ngIf=\"showHint\" class=\"help-block\" [innerHTML]=\"model.hint\" [ngClass]=\"getClass('element', 'hint')\"></span><timepicker *ngSwitchCase=\"9\" [arrowkeys]=\"getAdditional('arrowkeys', true)\" [dynamicId]=\"bindId && model.id\" [formControlName]=\"model.id\" [hourStep]=\"getAdditional('hourStep', 1)\" [max]=\"model.max\" [min]=\"model.min\" [mousewheel]=\"getAdditional('mousewheel', true)\" [minuteStep]=\"getAdditional('minuteStep', 1)\" [ngClass]=\"getClass('element', 'control')\" [secondsStep]=\"getAdditional('secondsStep', 1)\" [showMeridian]=\"model.meridian\" [showSeconds]=\"model.showSeconds\" [showSpinners]=\"getAdditional('spinners', true)\"></timepicker></ng-container></div><ul *ngIf=\"showErrorMessages\" class=\"has-error\" [ngClass]=\"[getClass('element', 'errors'), getClass('grid', 'errors')]\"><li *ngFor=\"let message of errorMessages\" class=\"help-block\">{{ message }}</li></ul><ng-container *ngTemplateOutlet=\"templates[1]?.templateRef; context: model\"></ng-container><ng-content></ng-content></div>"
            },] },
];
/** @nocollapse */
DynamicBootstrapFormControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef, },
    { type: DynamicFormLayoutService, },
    { type: DynamicFormValidationService, },
];
DynamicBootstrapFormControlComponent.propDecorators = {
    "contentTemplateList": [{ type: ContentChildren, args: [DynamicTemplateDirective,] },],
    "inputTemplateList": [{ type: Input, args: ["templates",] },],
    "asBootstrapFormGroup": [{ type: Input },],
    "bindId": [{ type: Input },],
    "context": [{ type: Input },],
    "group": [{ type: Input },],
    "hasErrorMessaging": [{ type: Input },],
    "layout": [{ type: Input },],
    "model": [{ type: Input },],
    "blur": [{ type: Output, args: ["dfBlur",] },],
    "change": [{ type: Output, args: ["dfChange",] },],
    "focus": [{ type: Output, args: ["dfFocus",] },],
    "customEvent": [{ type: Output, args: ["bsEvent",] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class DynamicBootstrapFormComponent extends DynamicFormComponent {
    /**
     * @param {?} formService
     * @param {?} layoutService
     */
    constructor(formService, layoutService) {
        super(formService, layoutService);
        this.formService = formService;
        this.layoutService = layoutService;
        this.blur = new EventEmitter();
        this.change = new EventEmitter();
        this.focus = new EventEmitter();
    }
}
DynamicBootstrapFormComponent.decorators = [
    { type: Component, args: [{
                selector: "dynamic-bootstrap-form",
                template: "<dynamic-bootstrap-form-control *ngFor=\"let model of formModel; trackBy: trackByFn\" [group]=\"formGroup\" [hasErrorMessaging]=\"model.hasErrorMessages\" [hidden]=\"model.hidden\" [layout]=\"formLayout\" [model]=\"model\" [ngClass]=\"[getClass(model,'element','host'), getClass(model,'grid','host')]\" [templates]=\"templates\" (dfBlur)=\"onEvent($event, 'blur')\" (dfChange)=\"onEvent($event, 'change')\" (dfFocus)=\"onEvent($event, 'focus')\"></dynamic-bootstrap-form-control>"
            },] },
];
/** @nocollapse */
DynamicBootstrapFormComponent.ctorParameters = () => [
    { type: DynamicFormService, },
    { type: DynamicFormLayoutService, },
];
DynamicBootstrapFormComponent.propDecorators = {
    "formGroup": [{ type: Input, args: ["group",] },],
    "formModel": [{ type: Input, args: ["model",] },],
    "formLayout": [{ type: Input, args: ["layout",] },],
    "blur": [{ type: Output, args: ["dfBlur",] },],
    "change": [{ type: Output, args: ["dfChange",] },],
    "focus": [{ type: Output, args: ["dfFocus",] },],
    "templates": [{ type: ContentChildren, args: [DynamicTemplateDirective,] },],
    "components": [{ type: ViewChildren, args: [DynamicBootstrapFormControlComponent,] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class DynamicFormsBootstrapUIModule {
}
DynamicFormsBootstrapUIModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    ReactiveFormsModule,
                    BsDatepickerModule.forRoot(),
                    TimepickerModule.forRoot(),
                    TextMaskModule,
                    DynamicFormsCoreModule
                ],
                declarations: [
                    DynamicBootstrapFormControlComponent,
                    DynamicBootstrapFormComponent
                ],
                exports: [
                    DynamicFormsCoreModule,
                    DynamicBootstrapFormControlComponent,
                    DynamicBootstrapFormComponent
                ]
            },] },
];
/** @nocollapse */
DynamicFormsBootstrapUIModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

export { DynamicBootstrapFormComponent, DynamicBootstrapFormControlComponent, DynamicFormsBootstrapUIModule };
//# sourceMappingURL=ui-bootstrap.js.map
